@@ -2,17 +2,17 @@
 `Objects` library.
 """
 
-from .catalog import Catalog
+from .catalog import Catalog, overrides
 from .providers import (Provider, NewInstance, Singleton, Class, Object,
                         Function, Value)
-from .injections import InitArg, Attribute, Method, inject
+from .injections import InitArg, Attribute, Method
 
 
-__all__ = ['Catalog',
+__all__ = ['Catalog', 'overrides',
 
            # Providers
            'Provider', 'NewInstance', 'Singleton', 'Class',
            'Object', 'Function', 'Value',
 
            # Injections
-           'InitArg', 'Attribute', 'Method', 'inject']
+           'InitArg', 'Attribute', 'Method']
